﻿using System.Collections.Generic;
using System.Drawing;

namespace ShareReadability.Container
{
    /// @file Sentence.cs
    /// <summary>
    /// This class represents a container for a sentence.
    /// </summary>
    public class Sentence
    {
        // The raw text
        public string Text { get; set; }

        // The plaintext without LaTeX commands
        public string PlainText { get; set; }

        // The highlight color
        public Color Color { get; set; }

        // The verbs and nouns of this sentence
        public List<string> Verbs { get; set; }
        public List<string> Nouns { get; set; }

        // Average of the features
        public float AverageForSentence { get; set; }

        // Features
        public float AverageWordLength { get; set; }
        public float SentenceLength { get; set; }
        public float VocabularyComplexity { get; set; }
        public float NounToVerbRatio { get; set; }
        public float SentenceStructureComplexity { get; set; }



        /// <summary>
        /// Generates a string representation of the sentence.
        /// </summary>
        /// <returns>A string representation of the sentence.</returns>
        public override string ToString()
        {
            var s = "";
            s += "Average for Sentence: " + AverageForSentence + "\n\n";

            s += "Average Word Length: " + AverageWordLength + "\n";
            s += "Vocabulary Complexity: " + VocabularyComplexity + "\n";
            s += "Noun to Verb Ratio: " + NounToVerbRatio + "\n";
            s += "Sentence Length: " + SentenceLength + "\n";
            s += "Sentence Structure Complexity: " + SentenceStructureComplexity;

            return s;
        }

        /// <summary>
        /// Generates a string representation of the sentence to display it as comment.
        /// </summary>
        /// <returns>A string representation to use as a comment.</returns>
        public string GenerateComment()
        {
            var s = "";
            s += string.Format("Average for Sentence: {0:0.00}\\textCR\\textCR ", AverageForSentence);


            s += string.Format("Average Word Length: {0:0.00}\\textCR ", AverageWordLength);
            s += string.Format("Vocabulary Complexity: {0:0.00}\\textCR ", VocabularyComplexity);
            s += string.Format("Noun to Verb Ratio: {0:0.00}\\textCR ", NounToVerbRatio);
            s += string.Format("Sentence Length: {0:0.00}\\textCR ", SentenceLength);
            s += string.Format("Sentence Structure Complexity: {0:0.00}", SentenceStructureComplexity);

            return s;
        }
    }
}