﻿using System.Collections.Generic;
using System.IO;

namespace ShareReadability.Container
{
    /// @file Settings.cs
    /// <summary>
    /// This class represents a container for the settings from the GUI.
    /// </summary>
    public class Settings
    {
        private const string DefaultDictionary = "data/dictionary/1000_most_common_english_words.txt";
        private const string DefaultWhitelist = "data/whitelist.txt";

        /// <summary>
        /// Constructor of the settings.
        /// </summary>
        public Settings()
        {
            WhitelistPath = DefaultWhitelist;
            DictionaryPath = Path.Combine(Directory.GetCurrentDirectory(), DefaultDictionary);
            Dictionary = new List<string>(File.ReadAllLines(DictionaryPath));
            AverageWordLengthWeight = 0.2f;
            SentenceLengthWeight = 0.2f;
            VocabularyComplexityWeight = 0.2f;
            NominalFormsWeight = 0.2f;
            SentenceStructureComplexityWeight = 0.2f;
        }

        // Whitelist
        public string WhitelistPath { get; set; }

        // Dictionary
        public string DictionaryPath { get; set; }
        public List<string> Dictionary { get; set; }

        // Weights for the features
        public float AverageWordLengthWeight { get; set; }
        public float SentenceLengthWeight { get; set; }
        public float VocabularyComplexityWeight { get; set; }
        public float NominalFormsWeight { get; set; }
        public float SentenceStructureComplexityWeight { get; set; }
    }
}