﻿using System.Windows;
using CefSharp;
using ShareReadability.Util;
using System.Text.RegularExpressions;
using ShareReadability.Container;

namespace ShareReadability
{
	/// @file MainWindow.xaml.cs
	/// <inheritdoc cref="Window" />
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		private const string TargetUrl = "https://www.sharelatex.com/project/(.+)";
		private SettingsWindow _settingsWindow;
		public Settings Settings { get; set; }

		/// <inheritdoc />
		/// <summary>
		/// Constructor of the main window.
		/// </summary>
		public MainWindow()
		{
			InitializeComponent();

			// Initialize CefSharp browser
			ChromiumWebBrowser.DownloadHandler = new DownloadHandler();
			ChromiumWebBrowser.LifeSpanHandler = new LifeSpanHandler();
			ChromiumWebBrowser.FrameLoadEnd += ChromiumWebBrowserOnFrameLoadEnd;

			// Initialize Settings
			Settings = new Settings();
			
			// Initialize Readability Analysis
			ReadabilityAnalysis.ReadabilityAnalysisPipeline.MainWindow = this;
			ReadabilityAnalysis.ReadabilityAnalysisPipeline.Settings = Settings;
			ReadabilityAnalysis.ReadabilityAnalysisPipeline.Initialize();
		}

		/// <summary>
		/// Enables the main menu if the URL is equal some specified target URL.
		/// So the main menu is only active at the LaTeX Editor.
		/// </summary>
		/// <param name="sender">The sender.</param>
		/// <param name="frameLoadEndEventArgs">The event.</param>
		private void ChromiumWebBrowserOnFrameLoadEnd(object sender, FrameLoadEndEventArgs frameLoadEndEventArgs)
		{
			var currentUrl = frameLoadEndEventArgs.Url;
			ChromiumWebBrowser.Dispatcher.InvokeAsync(() => MainMenu.IsEnabled = Regex.IsMatch(currentUrl, TargetUrl));
		}

		/// <summary>
		/// Executes the readability analysis pipeline.
		/// </summary>
		/// <param name="sender">The sender.</param>
		/// <param name="e">The event.</param>
		private void MenuItem_OnClick_Analyze(object sender, RoutedEventArgs e)
		{
			ReadabilityAnalysis.ReadabilityAnalysisPipeline.ExecutePipeline(ChromiumWebBrowser);
		}

		/// <summary>
		/// Opens the settings window.
		/// </summary>
		/// <param name="sender">The sender.</param>
		/// <param name="e">The event.</param>
		private void MenuItem_OnClick_Settings(object sender, RoutedEventArgs e)
		{
			_settingsWindow = new SettingsWindow {Settings = Settings};
			_settingsWindow.InitializeSlider();
			_settingsWindow.ShowDialog();
		}

		/// <summary>
		/// Enables/Disables the main menu.
		/// </summary>
		/// <param name="enabled">If the main menu should be enabled.</param>
		public void EnableMainMenu(bool enabled)
		{
			MainMenu.IsEnabled = enabled;
		}
	}
}