﻿using System;
using CefSharp;

namespace ShareReadability.Util
{
    /// @file DownloadHandler.cs
    /// <inheritdoc />
    /// <summary>
    /// DownloadHandler from CefSharp examples to handle the downloads.
    /// https://github.com/cefsharp/CefSharp/blob/master/CefSharp.Example/DownloadHandler.cs
    /// </summary>
    public class DownloadHandler : IDownloadHandler
    {
        public event EventHandler<DownloadItem> OnBeforeDownloadFired;
        public event EventHandler<DownloadItem> OnDownloadUpdatedFired;

        /// <summary>
        /// Handles the downloading of a file. Opens a save file dialog.
        /// </summary>
        /// <param name="browser">The browser that wants to download</param>
        /// <param name="downloadItem">The item to download.</param>
        /// <param name="callback">The callback to continue downloading.</param>
        public void OnBeforeDownload(IBrowser browser, DownloadItem downloadItem, IBeforeDownloadCallback callback)
        {
            var handler = OnBeforeDownloadFired;
            if (handler != null)
            {
                handler(this, downloadItem);
            }

            if (!callback.IsDisposed)
            {
                using (callback)
                {
                    callback.Continue(downloadItem.SuggestedFileName, showDialog: true);
                }
            }
        }

        /// <summary>
        /// Handles the downloading of a file.
        /// </summary>
        /// <param name="browser">The browser that wants to download</param>
        /// <param name="downloadItem">The item to download.</param>
        /// <param name="callback">The callback used to cancel a download.</param>
        public void OnDownloadUpdated(IBrowser browser, DownloadItem downloadItem, IDownloadItemCallback callback)
        {
            var handler = OnDownloadUpdatedFired;
            if (handler != null)
            {
                handler(this, downloadItem);
            }
        }
    }
}